@@ -12,8 +12,13 @@ def cmap_from_model(model: BaseModel, skip_none=True) -> CommentedMap:
         if value is MISSING or (skip_none and value is None):
             continue
 
+        field_info = field.field_info
+
         yaml_key = field.alias
-        description = field.field_info.description
+        description = field_info.description
+
+        if not field_info.extra.get('in_file', True):
+            continue
 
         if isinstance(value, BaseModel):
             cmap[yaml_key] = cmap_from_model(value)
@@ -27,7 +32,15 @@ def cmap_from_model(model: BaseModel, skip_none=True) -> CommentedMap:
 
         if not description:
             continue
+
+        # Don't overwrite comment
         if yaml_key not in cmap.ca.items:
-            cmap.yaml_add_eol_comment(description, yaml_key)
+            # Ensure that every line in the comment that has chars has a comment sign
+            comment_lines = []
+            for line in description.splitlines():
+                _line = line.lstrip()
+                comment_lines.append(('# ' + line) if _line and not _line.startswith('#') else line)
+
+            cmap.yaml_add_eol_comment('\n'.join(comment_lines), yaml_key)
 
     return cmap
